@@ -139,8 +139,8 @@ enum  {
 	TRACKER_METADATA_TILE_QUERY,
 	TRACKER_METADATA_TILE_RESULT_GRID
 };
-static void tracker_metadata_tile_AttachToTable (TrackerMetadataTile* self, GtkLabel* lab, gint l, gint r, gint t, gint b);
-static GtkLabel* tracker_metadata_tile_CreateLabel (TrackerMetadataTile* self, const char* s);
+static void tracker_metadata_tile_AttachToTable (TrackerMetadataTile* self, GtkLabel* lab, gint l, gint r, gint t, gint b, gboolean e);
+static GtkLabel* tracker_metadata_tile_CreateLabel (TrackerMetadataTile* self, const char* s, gboolean e);
 void tracker_metadata_tile_ClearLabels (TrackerMetadataTile* self);
 GType result_columns_get_type (void);
 TrackerQuery* tracker_metadata_tile_get_Query (TrackerMetadataTile* self);
@@ -159,75 +159,81 @@ static void tracker_metadata_tile_get_property (GObject * object, guint property
 static void tracker_metadata_tile_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
 static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
-static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-#line 134 "tracker-metadata-tile.gs"
-static void tracker_metadata_tile_AttachToTable (TrackerMetadataTile* self, GtkLabel* lab, gint l, gint r, gint t, gint b) {
-#line 134 "tracker-metadata-tile.gs"
+#line 133 "tracker-metadata-tile.gs"
+static void tracker_metadata_tile_AttachToTable (TrackerMetadataTile* self, GtkLabel* lab, gint l, gint r, gint t, gint b, gboolean e) {
+#line 133 "tracker-metadata-tile.gs"
 	g_return_if_fail (self != NULL);
-#line 134 "tracker-metadata-tile.gs"
+#line 133 "tracker-metadata-tile.gs"
 	g_return_if_fail (lab != NULL);
+#line 134 "tracker-metadata-tile.gs"
+	if (e == TRUE) {
 #line 135 "tracker-metadata-tile.gs"
-	gtk_table_attach (self->table, (GtkWidget*) lab, (guint) l, (guint) r, (guint) t, (guint) b, GTK_FILL | GTK_SHRINK, GTK_FILL, (guint) 0, (guint) 0);
-#line 175 "tracker-metadata-tile.c"
+		gtk_table_attach (self->table, (GtkWidget*) lab, (guint) l, (guint) r, (guint) t, (guint) b, GTK_FILL | GTK_EXPAND, GTK_FILL, (guint) 0, (guint) 0);
+#line 176 "tracker-metadata-tile.c"
+	} else {
+#line 137 "tracker-metadata-tile.gs"
+		gtk_table_attach (self->table, (GtkWidget*) lab, (guint) l, (guint) r, (guint) t, (guint) b, GTK_FILL, GTK_FILL, (guint) 0, (guint) 0);
+#line 180 "tracker-metadata-tile.c"
+	}
 }
 
 
-#line 138 "tracker-metadata-tile.gs"
-static GtkLabel* tracker_metadata_tile_CreateLabel (TrackerMetadataTile* self, const char* s) {
-#line 181 "tracker-metadata-tile.c"
+#line 139 "tracker-metadata-tile.gs"
+static GtkLabel* tracker_metadata_tile_CreateLabel (TrackerMetadataTile* self, const char* s, gboolean e) {
+#line 187 "tracker-metadata-tile.c"
 	GtkLabel* result;
 	GtkLabel* l;
-#line 138 "tracker-metadata-tile.gs"
+#line 139 "tracker-metadata-tile.gs"
 	g_return_val_if_fail (self != NULL, NULL);
-#line 138 "tracker-metadata-tile.gs"
+#line 139 "tracker-metadata-tile.gs"
 	g_return_val_if_fail (s != NULL, NULL);
-#line 188 "tracker-metadata-tile.c"
+#line 194 "tracker-metadata-tile.c"
 	l = g_object_ref_sink ((GtkLabel*) gtk_label_new (s));
-#line 140 "tracker-metadata-tile.gs"
-	g_object_set ((GtkMisc*) l, "xalign", (float) 0, NULL);
 #line 141 "tracker-metadata-tile.gs"
+	g_object_set ((GtkMisc*) l, "xalign", (float) 0, NULL);
+#line 142 "tracker-metadata-tile.gs"
 	gtk_label_set_use_markup (l, TRUE);
-#line 143 "tracker-metadata-tile.gs"
-	if (_vala_strcmp0 (s, "") == 0) {
 #line 144 "tracker-metadata-tile.gs"
+	if (e == TRUE) {
+#line 145 "tracker-metadata-tile.gs"
 		gtk_label_set_ellipsize (l, PANGO_ELLIPSIZE_END);
-#line 198 "tracker-metadata-tile.c"
+#line 204 "tracker-metadata-tile.c"
 	}
 	result = l;
 	return result;
 }
 
 
-#line 149 "tracker-metadata-tile.gs"
-void tracker_metadata_tile_ClearLabels (TrackerMetadataTile* self) {
-#line 149 "tracker-metadata-tile.gs"
-	g_return_if_fail (self != NULL);
 #line 150 "tracker-metadata-tile.gs"
-	gtk_label_set_text (self->info_value1, "");
+void tracker_metadata_tile_ClearLabels (TrackerMetadataTile* self) {
+#line 150 "tracker-metadata-tile.gs"
+	g_return_if_fail (self != NULL);
 #line 151 "tracker-metadata-tile.gs"
-	gtk_label_set_text (self->info_value2, "");
+	gtk_label_set_text (self->info_value1, "");
 #line 152 "tracker-metadata-tile.gs"
-	gtk_label_set_text (self->info_value3, "");
+	gtk_label_set_text (self->info_value2, "");
 #line 153 "tracker-metadata-tile.gs"
-	gtk_label_set_text (self->info_value4, "");
+	gtk_label_set_text (self->info_value3, "");
 #line 154 "tracker-metadata-tile.gs"
-	gtk_label_set_text (self->info_value5, "");
+	gtk_label_set_text (self->info_value4, "");
 #line 155 "tracker-metadata-tile.gs"
-	gtk_label_set_text (self->info_value6, "");
+	gtk_label_set_text (self->info_value5, "");
 #line 156 "tracker-metadata-tile.gs"
-	gtk_link_button_set_uri (self->name_link, "");
+	gtk_label_set_text (self->info_value6, "");
 #line 157 "tracker-metadata-tile.gs"
+	gtk_link_button_set_uri (self->name_link, "");
+#line 158 "tracker-metadata-tile.gs"
 	gtk_button_set_label ((GtkButton*) self->name_link, "");
-#line 225 "tracker-metadata-tile.c"
+#line 231 "tracker-metadata-tile.c"
 }
 
 
-#line 162 "tracker-metadata-tile.gs"
+#line 163 "tracker-metadata-tile.gs"
 void tracker_metadata_tile_LoadUri (TrackerMetadataTile* self, const GtkTreePath* path) {
-#line 231 "tracker-metadata-tile.c"
+#line 237 "tracker-metadata-tile.c"
 	GError * _inner_error_;
 	GtkTreeIter iter = {0};
 	const char* uri;
@@ -236,40 +242,40 @@ void tracker_metadata_tile_LoadUri (TrackerMetadataTile* self, const GtkTreePath
 	GFile* file;
 	char* filepath;
 	char* query;
-#line 162 "tracker-metadata-tile.gs"
-	g_return_if_fail (self != NULL);
-#line 242 "tracker-metadata-tile.c"
-	_inner_error_ = NULL;
 #line 163 "tracker-metadata-tile.gs"
+	g_return_if_fail (self != NULL);
+#line 248 "tracker-metadata-tile.c"
+	_inner_error_ = NULL;
+#line 164 "tracker-metadata-tile.gs"
 	tracker_metadata_tile_ClearLabels (self);
-#line 165 "tracker-metadata-tile.gs"
-	if (path == NULL) {
 #line 166 "tracker-metadata-tile.gs"
+	if (path == NULL) {
+#line 167 "tracker-metadata-tile.gs"
 		gtk_image_set_from_icon_name (self->image, "text-x-generic", GTK_ICON_SIZE_DIALOG);
-#line 250 "tracker-metadata-tile.c"
+#line 256 "tracker-metadata-tile.c"
 		return;
 	}
 	uri = NULL;
 	display_name = NULL;
 	icon = NULL;
-#line 174 "tracker-metadata-tile.gs"
-	gtk_tree_model_get_iter ((GtkTreeModel*) self->priv->_result_grid->store, &iter, path);
 #line 175 "tracker-metadata-tile.gs"
+	gtk_tree_model_get_iter ((GtkTreeModel*) self->priv->_result_grid->store, &iter, path);
+#line 176 "tracker-metadata-tile.gs"
 	gtk_tree_model_get ((GtkTreeModel*) self->priv->_result_grid->store, &iter, RESULT_COLUMNS_Uri, &uri, RESULT_COLUMNS_Icon, &icon, RESULT_COLUMNS_DisplayName, &display_name, -1);
-#line 177 "tracker-metadata-tile.gs"
+#line 178 "tracker-metadata-tile.gs"
 	gtk_image_set_from_pixbuf (self->image, icon);
-#line 262 "tracker-metadata-tile.c"
+#line 268 "tracker-metadata-tile.c"
 	file = g_file_new_for_uri (uri);
-	filepath = g_file_get_path (file);
-#line 181 "tracker-metadata-tile.gs"
-	gtk_link_button_set_uri (self->name_link, uri);
+	filepath = g_file_get_basename (file);
 #line 182 "tracker-metadata-tile.gs"
+	gtk_link_button_set_uri (self->name_link, uri);
+#line 183 "tracker-metadata-tile.gs"
 	gtk_button_set_label ((GtkButton*) self->name_link, filepath);
-#line 269 "tracker-metadata-tile.c"
+#line 275 "tracker-metadata-tile.c"
 	query = g_strdup_printf ("SELECT ?mimetype WHERE {<%s> nie:mimeType ?mimeType.}", uri);
-#line 187 "tracker-metadata-tile.gs"
+#line 188 "tracker-metadata-tile.gs"
 	if (self->priv->_Query != NULL) {
-#line 273 "tracker-metadata-tile.c"
+#line 279 "tracker-metadata-tile.c"
 		char** _tmp2_;
 		gint _result__length2;
 		gint _result__length1;
@@ -279,26 +285,26 @@ void tracker_metadata_tile_LoadUri (TrackerMetadataTile* self, const GtkTreePath
 		gboolean _tmp3_;
 		_result_ = (_tmp2_ = tracker_query_Query (self->priv->_Query, query, &_tmp0_, &_tmp1_), _result__length1 = _tmp0_, _result__length2 = _tmp1_, _tmp2_);
 		_tmp3_ = FALSE;
-#line 190 "tracker-metadata-tile.gs"
+#line 191 "tracker-metadata-tile.gs"
 		if (_result_ != NULL) {
-#line 190 "tracker-metadata-tile.gs"
+#line 191 "tracker-metadata-tile.gs"
 			_tmp3_ = _result_[(0 * _result__length2) + 0] != NULL;
-#line 287 "tracker-metadata-tile.c"
+#line 293 "tracker-metadata-tile.c"
 		} else {
-#line 190 "tracker-metadata-tile.gs"
+#line 191 "tracker-metadata-tile.gs"
 			_tmp3_ = FALSE;
-#line 291 "tracker-metadata-tile.c"
+#line 297 "tracker-metadata-tile.c"
 		}
-#line 190 "tracker-metadata-tile.gs"
+#line 191 "tracker-metadata-tile.gs"
 		if (_tmp3_) {
-#line 295 "tracker-metadata-tile.c"
+#line 301 "tracker-metadata-tile.c"
 			char* val1;
 			val1 = g_strdup_printf ("<b>%s</b>", _result_[(0 * _result__length2) + 0]);
-#line 193 "tracker-metadata-tile.gs"
-			gtk_label_set_markup (self->info_value1, val1);
 #line 194 "tracker-metadata-tile.gs"
+			gtk_label_set_markup (self->info_value1, val1);
+#line 195 "tracker-metadata-tile.gs"
 			g_object_set ((GtkMisc*) self->info_value1, "xalign", (float) 0, NULL);
-#line 302 "tracker-metadata-tile.c"
+#line 308 "tracker-metadata-tile.c"
 			_g_free0 (val1);
 		}
 		{
@@ -316,15 +322,15 @@ void tracker_metadata_tile_LoadUri (TrackerMetadataTile* self, const GtkTreePath
 				goto __finally5;
 			}
 			val2 = (_tmp5_ = g_strdup_printf ("<b>%s</b>", _tmp4_ = g_strdup_printf ("%lli", g_file_info_get_size (info))), _g_free0 (_tmp4_), _tmp5_);
-#line 202 "tracker-metadata-tile.gs"
+#line 203 "tracker-metadata-tile.gs"
 			gtk_label_set_markup (self->info_value2, val2);
-#line 205 "tracker-metadata-tile.gs"
+#line 206 "tracker-metadata-tile.gs"
 			g_file_info_get_modification_time (info, &tm);
-#line 324 "tracker-metadata-tile.c"
+#line 330 "tracker-metadata-tile.c"
 			val3 = (_tmp7_ = g_strdup_printf ("<b>%s</b>", _tmp6_ = g_time_val_to_iso8601 (&tm)), _g_free0 (_tmp6_), _tmp7_);
-#line 209 "tracker-metadata-tile.gs"
+#line 210 "tracker-metadata-tile.gs"
 			gtk_label_set_markup (self->info_value3, val3);
-#line 328 "tracker-metadata-tile.c"
+#line 334 "tracker-metadata-tile.c"
 			_g_object_unref0 (info);
 			_g_free0 (val2);
 			_g_free0 (val3);
@@ -336,9 +342,9 @@ void tracker_metadata_tile_LoadUri (TrackerMetadataTile* self, const GtkTreePath
 			e = _inner_error_;
 			_inner_error_ = NULL;
 			{
-#line 212 "tracker-metadata-tile.gs"
+#line 213 "tracker-metadata-tile.gs"
 				g_print ("Could not get file info for %s\n", uri);
-#line 342 "tracker-metadata-tile.c"
+#line 348 "tracker-metadata-tile.c"
 				_g_error_free0 (e);
 			}
 		}
@@ -364,7 +370,7 @@ void tracker_metadata_tile_LoadUri (TrackerMetadataTile* self, const GtkTreePath
 
 #line 28 "tracker-metadata-tile.gs"
 TrackerMetadataTile* tracker_metadata_tile_construct (GType object_type) {
-#line 368 "tracker-metadata-tile.c"
+#line 374 "tracker-metadata-tile.c"
 	TrackerMetadataTile * self;
 	self = g_object_newv (object_type, 0, NULL);
 	return self;
@@ -375,7 +381,7 @@ TrackerMetadataTile* tracker_metadata_tile_construct (GType object_type) {
 TrackerMetadataTile* tracker_metadata_tile_new (void) {
 #line 28 "tracker-metadata-tile.gs"
 	return tracker_metadata_tile_construct (TYPE_TRACKER_METADATA_TILE);
-#line 379 "tracker-metadata-tile.c"
+#line 385 "tracker-metadata-tile.c"
 }
 
 
@@ -410,7 +416,7 @@ static gpointer _g_object_ref0 (gpointer self) {
 static void _lambda6_ (const GtkTreePath* path, TrackerMetadataTile* self) {
 #line 74 "tracker-metadata-tile.gs"
 	tracker_metadata_tile_LoadUri (self, path);
-#line 414 "tracker-metadata-tile.c"
+#line 420 "tracker-metadata-tile.c"
 }
 
 
@@ -423,13 +429,13 @@ void tracker_metadata_tile_set_ResultGrid (TrackerMetadataTile* self, TrackerRes
 	g_return_if_fail (self != NULL);
 #line 70 "tracker-metadata-tile.gs"
 	if (value != NULL) {
-#line 427 "tracker-metadata-tile.c"
+#line 433 "tracker-metadata-tile.c"
 		TrackerResultGrid* _tmp0_;
 #line 71 "tracker-metadata-tile.gs"
 		self->priv->_result_grid = (_tmp0_ = _g_object_ref0 (value), _g_object_unref0 (self->priv->_result_grid), _tmp0_);
 #line 73 "tracker-metadata-tile.gs"
 		g_signal_connect_object (self->priv->_result_grid, "selection-changed", (GCallback) __lambda6__tracker_result_grid_selection_changed, self, 0);
-#line 433 "tracker-metadata-tile.c"
+#line 439 "tracker-metadata-tile.c"
 	}
 	g_object_notify ((GObject *) self, "ResultGrid");
 }
@@ -463,74 +469,74 @@ static GObject * tracker_metadata_tile_constructor (GType type, guint n_construc
 #line 78 "tracker-metadata-tile.gs"
 		gtk_container_set_border_width ((GtkContainer*) self, (guint) 8);
 #line 80 "tracker-metadata-tile.gs"
-		self->table = (_tmp0_ = g_object_ref_sink ((GtkTable*) gtk_table_new ((guint) 3, (guint) 7, TRUE)), _g_object_unref0 (self->table), _tmp0_);
+		self->table = (_tmp0_ = g_object_ref_sink ((GtkTable*) gtk_table_new ((guint) 3, (guint) 7, FALSE)), _g_object_unref0 (self->table), _tmp0_);
+#line 81 "tracker-metadata-tile.gs"
+		gtk_table_set_col_spacings (self->table, (guint) 6);
 #line 82 "tracker-metadata-tile.gs"
-		g_object_set (self->table, "column-spacing", (guint) 0, NULL);
-#line 83 "tracker-metadata-tile.gs"
-		g_object_set (self->table, "row-spacing", (guint) 1, NULL);
-#line 85 "tracker-metadata-tile.gs"
+		gtk_table_set_row_spacings (self->table, (guint) 6);
+#line 84 "tracker-metadata-tile.gs"
 		gtk_container_add ((GtkContainer*) self, (GtkWidget*) self->table);
-#line 87 "tracker-metadata-tile.gs"
+#line 86 "tracker-metadata-tile.gs"
 		self->image = (_tmp1_ = g_object_ref_sink ((GtkImage*) gtk_image_new_from_icon_name ("text-x-generic", GTK_ICON_SIZE_DIALOG)), _g_object_unref0 (self->image), _tmp1_);
-#line 88 "tracker-metadata-tile.gs"
-		gtk_table_attach_defaults (self->table, (GtkWidget*) self->image, (guint) 0, (guint) 1, (guint) 0, (guint) 3);
-#line 90 "tracker-metadata-tile.gs"
+#line 87 "tracker-metadata-tile.gs"
+		gtk_table_attach (self->table, (GtkWidget*) self->image, (guint) 0, (guint) 1, (guint) 0, (guint) 3, GTK_FILL, GTK_FILL, (guint) 12, (guint) 0);
+#line 89 "tracker-metadata-tile.gs"
 		self->name_link = (_tmp2_ = g_object_ref_sink ((GtkLinkButton*) gtk_link_button_new ("")), _g_object_unref0 (self->name_link), _tmp2_);
-#line 91 "tracker-metadata-tile.gs"
+#line 90 "tracker-metadata-tile.gs"
 		g_object_set ((GtkButton*) self->name_link, "xalign", (float) 0, NULL);
-#line 92 "tracker-metadata-tile.gs"
-		gtk_table_attach_defaults (self->table, (GtkWidget*) self->name_link, (guint) 1, (guint) 7, (guint) 0, (guint) 1);
+#line 91 "tracker-metadata-tile.gs"
+		gtk_table_attach (self->table, (GtkWidget*) self->name_link, (guint) 1, (guint) 7, (guint) 0, (guint) 1, GTK_FILL, GTK_FILL, (guint) 0, (guint) 0);
+#line 93 "tracker-metadata-tile.gs"
+		self->info_label1 = (_tmp3_ = tracker_metadata_tile_CreateLabel (self, N_ ("Type:"), FALSE), _g_object_unref0 (self->info_label1), _tmp3_);
 #line 94 "tracker-metadata-tile.gs"
-		self->info_label1 = (_tmp3_ = tracker_metadata_tile_CreateLabel (self, N_ ("Type : ")), _g_object_unref0 (self->info_label1), _tmp3_);
-#line 95 "tracker-metadata-tile.gs"
-		tracker_metadata_tile_AttachToTable (self, self->info_label1, 1, 2, 1, 2);
+		tracker_metadata_tile_AttachToTable (self, self->info_label1, 1, 2, 1, 2, FALSE);
+#line 96 "tracker-metadata-tile.gs"
+		self->info_value1 = (_tmp4_ = tracker_metadata_tile_CreateLabel (self, "-", TRUE), _g_object_unref0 (self->info_value1), _tmp4_);
 #line 97 "tracker-metadata-tile.gs"
-		self->info_value1 = (_tmp4_ = tracker_metadata_tile_CreateLabel (self, ""), _g_object_unref0 (self->info_value1), _tmp4_);
-#line 98 "tracker-metadata-tile.gs"
-		tracker_metadata_tile_AttachToTable (self, self->info_value1, 2, 3, 1, 2);
+		tracker_metadata_tile_AttachToTable (self, self->info_value1, 2, 3, 1, 2, TRUE);
+#line 99 "tracker-metadata-tile.gs"
+		self->info_label2 = (_tmp5_ = tracker_metadata_tile_CreateLabel (self, N_ ("Size:"), FALSE), _g_object_unref0 (self->info_label2), _tmp5_);
 #line 100 "tracker-metadata-tile.gs"
-		self->info_label2 = (_tmp5_ = tracker_metadata_tile_CreateLabel (self, N_ ("Size : ")), _g_object_unref0 (self->info_label2), _tmp5_);
-#line 101 "tracker-metadata-tile.gs"
-		tracker_metadata_tile_AttachToTable (self, self->info_label2, 3, 4, 1, 2);
+		tracker_metadata_tile_AttachToTable (self, self->info_label2, 3, 4, 1, 2, FALSE);
+#line 102 "tracker-metadata-tile.gs"
+		self->info_value2 = (_tmp6_ = tracker_metadata_tile_CreateLabel (self, "-", TRUE), _g_object_unref0 (self->info_value2), _tmp6_);
 #line 103 "tracker-metadata-tile.gs"
-		self->info_value2 = (_tmp6_ = tracker_metadata_tile_CreateLabel (self, ""), _g_object_unref0 (self->info_value2), _tmp6_);
-#line 104 "tracker-metadata-tile.gs"
-		tracker_metadata_tile_AttachToTable (self, self->info_value2, 4, 5, 1, 2);
+		tracker_metadata_tile_AttachToTable (self, self->info_value2, 4, 5, 1, 2, TRUE);
+#line 105 "tracker-metadata-tile.gs"
+		self->info_label3 = (_tmp7_ = tracker_metadata_tile_CreateLabel (self, N_ ("Modified:"), FALSE), _g_object_unref0 (self->info_label3), _tmp7_);
 #line 106 "tracker-metadata-tile.gs"
-		self->info_label3 = (_tmp7_ = tracker_metadata_tile_CreateLabel (self, N_ ("Modified : ")), _g_object_unref0 (self->info_label3), _tmp7_);
-#line 107 "tracker-metadata-tile.gs"
-		tracker_metadata_tile_AttachToTable (self, self->info_label3, 5, 6, 1, 2);
+		tracker_metadata_tile_AttachToTable (self, self->info_label3, 5, 6, 1, 2, FALSE);
+#line 108 "tracker-metadata-tile.gs"
+		self->info_value3 = (_tmp8_ = tracker_metadata_tile_CreateLabel (self, "-", TRUE), _g_object_unref0 (self->info_value3), _tmp8_);
 #line 109 "tracker-metadata-tile.gs"
-		self->info_value3 = (_tmp8_ = tracker_metadata_tile_CreateLabel (self, ""), _g_object_unref0 (self->info_value3), _tmp8_);
-#line 110 "tracker-metadata-tile.gs"
-		tracker_metadata_tile_AttachToTable (self, self->info_value3, 6, 7, 1, 2);
+		tracker_metadata_tile_AttachToTable (self, self->info_value3, 6, 7, 1, 2, TRUE);
+#line 111 "tracker-metadata-tile.gs"
+		self->info_label4 = (_tmp9_ = tracker_metadata_tile_CreateLabel (self, N_ ("Title:"), FALSE), _g_object_unref0 (self->info_label4), _tmp9_);
 #line 112 "tracker-metadata-tile.gs"
-		self->info_label4 = (_tmp9_ = tracker_metadata_tile_CreateLabel (self, N_ ("Title : ")), _g_object_unref0 (self->info_label4), _tmp9_);
-#line 113 "tracker-metadata-tile.gs"
-		tracker_metadata_tile_AttachToTable (self, self->info_label4, 1, 2, 2, 3);
+		tracker_metadata_tile_AttachToTable (self, self->info_label4, 1, 2, 2, 3, FALSE);
+#line 114 "tracker-metadata-tile.gs"
+		self->info_value4 = (_tmp10_ = tracker_metadata_tile_CreateLabel (self, "-", TRUE), _g_object_unref0 (self->info_value4), _tmp10_);
 #line 115 "tracker-metadata-tile.gs"
-		self->info_value4 = (_tmp10_ = tracker_metadata_tile_CreateLabel (self, ""), _g_object_unref0 (self->info_value4), _tmp10_);
-#line 116 "tracker-metadata-tile.gs"
-		tracker_metadata_tile_AttachToTable (self, self->info_value4, 2, 3, 2, 3);
+		tracker_metadata_tile_AttachToTable (self, self->info_value4, 2, 3, 2, 3, TRUE);
+#line 117 "tracker-metadata-tile.gs"
+		self->info_label5 = (_tmp11_ = tracker_metadata_tile_CreateLabel (self, N_ ("Author/Artist:"), FALSE), _g_object_unref0 (self->info_label5), _tmp11_);
 #line 118 "tracker-metadata-tile.gs"
-		self->info_label5 = (_tmp11_ = tracker_metadata_tile_CreateLabel (self, N_ ("Author/Artist : ")), _g_object_unref0 (self->info_label5), _tmp11_);
-#line 119 "tracker-metadata-tile.gs"
-		tracker_metadata_tile_AttachToTable (self, self->info_label5, 3, 4, 2, 3);
+		tracker_metadata_tile_AttachToTable (self, self->info_label5, 3, 4, 2, 3, FALSE);
+#line 120 "tracker-metadata-tile.gs"
+		self->info_value5 = (_tmp12_ = tracker_metadata_tile_CreateLabel (self, "-", TRUE), _g_object_unref0 (self->info_value5), _tmp12_);
 #line 121 "tracker-metadata-tile.gs"
-		self->info_value5 = (_tmp12_ = tracker_metadata_tile_CreateLabel (self, ""), _g_object_unref0 (self->info_value5), _tmp12_);
-#line 122 "tracker-metadata-tile.gs"
-		tracker_metadata_tile_AttachToTable (self, self->info_value5, 4, 5, 2, 3);
+		tracker_metadata_tile_AttachToTable (self, self->info_value5, 4, 5, 2, 3, TRUE);
+#line 123 "tracker-metadata-tile.gs"
+		self->info_label6 = (_tmp13_ = tracker_metadata_tile_CreateLabel (self, "Comments:", FALSE), _g_object_unref0 (self->info_label6), _tmp13_);
 #line 124 "tracker-metadata-tile.gs"
-		self->info_label6 = (_tmp13_ = tracker_metadata_tile_CreateLabel (self, "Comments : "), _g_object_unref0 (self->info_label6), _tmp13_);
-#line 125 "tracker-metadata-tile.gs"
-		tracker_metadata_tile_AttachToTable (self, self->info_label6, 5, 6, 2, 3);
+		tracker_metadata_tile_AttachToTable (self, self->info_label6, 5, 6, 2, 3, FALSE);
+#line 126 "tracker-metadata-tile.gs"
+		self->info_value6 = (_tmp14_ = tracker_metadata_tile_CreateLabel (self, "-", TRUE), _g_object_unref0 (self->info_value6), _tmp14_);
 #line 127 "tracker-metadata-tile.gs"
-		self->info_value6 = (_tmp14_ = tracker_metadata_tile_CreateLabel (self, ""), _g_object_unref0 (self->info_value6), _tmp14_);
-#line 128 "tracker-metadata-tile.gs"
-		tracker_metadata_tile_AttachToTable (self, self->info_value6, 6, 7, 2, 3);
-#line 130 "tracker-metadata-tile.gs"
+		tracker_metadata_tile_AttachToTable (self, self->info_value6, 6, 7, 2, 3, TRUE);
+#line 129 "tracker-metadata-tile.gs"
 		gtk_widget_show_all ((GtkWidget*) self);
-#line 534 "tracker-metadata-tile.c"
+#line 540 "tracker-metadata-tile.c"
 	}
 	return obj;
 }
@@ -643,16 +649,5 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 }
 
 
-static int _vala_strcmp0 (const char * str1, const char * str2) {
-	if (str1 == NULL) {
-		return -(str1 != str2);
-	}
-	if (str2 == NULL) {
-		return str1 != str2;
-	}
-	return strcmp (str1, str2);
-}
-
-
 
 
